@@ -4,13 +4,14 @@ Created on Tue May  4 15:59:03 2021
 
 @author: braxt
 """
+from _typeshed import NoneType
 from math import log
 import time
 import sys
 
 
 class ProgressBar(object):
-    def __init__(self, items=None, completed=0, maxlen=25, char='█', show_on_update=False, ips=1, lsttime=None):
+    def __init__(self, items=None, completed=0, maxlen=25, char='█', show_on_update=False, ips=1, lsttime=None, learning_rate=.1):
         self.completed = completed
         self.items = items
         self.maxlen = maxlen
@@ -21,6 +22,7 @@ class ProgressBar(object):
             self.last_time = lsttime
         else:
             self.last_time = time.time()
+        self.lr = learning_rate
         self.show_on_update = show_on_update
 
     def __repr__(self):
@@ -43,7 +45,7 @@ class ProgressBar(object):
 
     def __iadd__(self, other):
         a = ProgressBar(self.items, self.completed, self.maxlen, self.char,
-                        self.show_on_update, self.items_per_sec, self.last_time)
+                        self.show_on_update, self.items_per_sec, self.last_time, self.lr)
         a.update(self.completed + other)
         return a
 
@@ -66,15 +68,20 @@ class ProgressBar(object):
 {str(round(self.pos*100,2)).ljust(5)}% \
 [{(self.char*int(self.pos*self.maxlen)).ljust(self.maxlen)}] {st}\t\r')
 
-    def update(self, completed):
+    def update(self, completed=None):
+        if isinstance(completed, NoneType):
+            completed = self.completed + 1
         if self.items:
             t = time.time() - self.last_time
             if t != 0:
                 comp = completed - self.completed
-                self.items_per_sec += .1 * (comp/t - self.items_per_sec)
+                self.items_per_sec += self.lr * (comp/t - self.items_per_sec)
                 self.last_time = time.time()
                 self.completed = completed
                 self.pos = completed/self.items
+            elif completed == self.items:
+                self.completed = completed
+                self.pos = completed/self.items
         else:
             self.pos = completed
         if self.show_on_update:
@@ -83,6 +90,6 @@ class ProgressBar(object):
 
 if __name__ == '__main__':
     import random
-    prog = ProgressBar(100000, show_on_update=True, ips=1.5)
+    prog = ProgressBar(5, show_on_update=True, ips=1.5)
     for i in range(prog.items):
-        prog.update(i)
+        prog.update(i+1)
